# eric7.Plugins.VcsPlugins.vcsMercurial.HgRevisionSelectionDialog

Module implementing a dialog to select a revision.

### Global Attributes

None

### Classes

HgRevisionSelectionDialog | Class implementing a dialog to select a revision.

### Functions

None

## HgRevisionSelectionDialog

Class implementing a dialog to select a revision.

### Derived from

QDialog, Ui_HgRevisionSelectionDialog

### Class Attributes

None

### Class Methods

None

### Methods

HgRevisionSelectionDialog | Constructor
__updateOK | Private slot to update the OK button.
getRevision | Public method to retrieve the selected revision.

### Static Methods

None

#### HgRevisionSelectionDialog (Constructor)

HgRevisionSelectionDialog(tagsList, branchesList, bookmarksList=None, noneLabel="", revset=True, parent=None, )

Constructor

tagsList (list of str)
  list of tags
branchesList (list of str)
  list of branches
bookmarksList (list of str)
  list of bookmarks
noneLabel (str)
  labeltext for "no revision selected"
revset (bool)
  flag indicating to allow the revision or ID given as a revset
parent (QWidget)
  parent widget

#### HgRevisionSelectionDialog.__updateOK

__updateOK()

Private slot to update the OK button.

#### HgRevisionSelectionDialog.getRevision

getRevision()

Public method to retrieve the selected revision.

Return:
  selected revision

Return Type:
  str

Up